<!--

*******************************************************************************

Please ask questions in our forum at 

https://discuss.elastic.co/tags/c/elastic-stack/elasticsearch/rally

GitHub is reserved for bug reports and feature requests only and we will 
close your issue immediately if it is just a question.
 
*******************************************************************************

If you are in fact posting a bug report or a feature request, please include 
one and only one of the below blocks in your new issue.

-->

<!--
If you are filing a bug report, please remove the below feature
request block and provide responses for all of the below items.
-->

**Rally version** (get with `esrally --version`):

**Invoked command**:

**Configuration file (located in `~/.rally/rally.ini`))**:

**JVM version**:

**OS version**:

**Description of the problem including expected versus actual behavior**:

**Steps to reproduce**:
 1.
 2.
 3.

**Provide logs (if relevant)**:

<!--
If you are filing a feature request, please remove the above bug
report block and provide responses for all of the below items.
-->

**Describe the feature**:
